@@ -40,45 +40,48 @@
 int main(int argc, char *argv[])
 
 {
-  system_init(argc, argv);
-  effects_init();
-  main_initpass();
-  for (kcycleidx=kbase; kcycleidx<=endkcycle; kcycleidx++)
+  ENGINE_PTR_DECLARE_SEMICOLON
+  int busidx;
+
+  ENGINE_PTR_ASSIGNED_TO  system_init(argc, argv, SAOL_SRATE);
+  if (ENGINE_PTR_IS_NULL) return -1;
+  effects_init(ENGINE_PTR);
+  main_initpass(ENGINE_PTR);
+  for (EV(kcycleidx)=EV(kbase); EV(kcycleidx)<=EV(endkcycle); EV(kcycleidx)++)
     {
-      pass = IPASS;
-      scorebeats = scoremult*(kcycleidx - kbase) + scorebase;
-      absolutetime = (kcycleidx - 1)*KTIME;
-      main_ipass();
-      pass = KPASS;
-      main_control();
-      if (main_kpass())
+      EV(pass) = IPASS;
+      EV(scorebeats) = EV(scoremult)*(EV(kcycleidx) - EV(kbase)) + EV(scorebase);
+      EV(absolutetime) = (EV(kcycleidx) - 1)*EV(KTIME);
+      main_ipass(ENGINE_PTR);
+      EV(pass) = KPASS;
+      main_control(ENGINE_PTR);
+      if (main_kpass(ENGINE_PTR))
 	break;
-      pass = APASS;
-      for (acycleidx=0; acycleidx<ACYCLE; acycleidx++)
+      EV(pass) = APASS;
+      for (EV(acycleidx)=0; EV(acycleidx)<EV(ACYCLE); EV(acycleidx)++)
 	{
-	  for (busidx=0; busidx<ENDBUS;busidx++)
-	    bus[busidx]=0.0F;
-	  main_apass();
+	  memset(&(TB(0)), 0, sizeof(TB(0))*ENDBUS);
+	  main_apass(ENGINE_PTR);
 	  for (busidx=BUS_output_bus; busidx<ENDBUS_output_bus;busidx++)
 	    {
-	      bus[busidx] = (bus[busidx] >  1.0F) ?  1.0F : bus[busidx];
-	      asys_obuf[obusidx++] = (bus[busidx] < -1.0F) ? -1.0F:bus[busidx];
+	      TB(busidx) = (TB(busidx) >  1.0F) ?  1.0F : TB(busidx);
+	      EV(asys_obuf)[EV(obusidx)++] = (TB(busidx) < -1.0F) ? -1.0F:TB(busidx);
 	    }
-	  if (obusidx >= asys_osize)
+	  if (EV(obusidx) >= EV(asys_osize))
 	    {
-	      obusidx = 0;
-	      if (asys_putbuf(&asys_obuf, &asys_osize))
+	      EV(obusidx) = 0;
+	      if (asys_putbuf(&EV(asys_obuf), &EV(asys_osize)))
 		{
 		  fprintf(stderr,"  Sfront: Audio output device problem\n\n");
-		  kcycleidx = endkcycle;
+		  EV(kcycleidx) = EV(endkcycle);
 		  break;
 		}
 	    }
 	}
-      acycleidx = 0; 
-      cpuload = ksync();
+      EV(acycleidx) = 0; 
+      EV(cpuload) = ksync();
     }
-  shut_down();
+  shut_down(ENGINE_PTR);
   return 0;
 }
 
