@@ -40,7 +40,7 @@
 #ifndef _SFRONT_TREE_H
 #define _SFRONT_TREE_H 1
 
-#define IDSTRING "0.95 12/28/09"
+#define IDSTRING "0.97 03/08/10"
 
 #include <stdio.h>
 #include <math.h>
@@ -664,7 +664,7 @@ extern void * alloca(size_t);
 
 /* directory pre-prcoesss looks for SAOL library by default */
 
-#define SAOLLIBDIR  "/usr/lib/sfront"
+#define SAOLLIBDIR  "/usr/share/sfront"
 
 /* types of input/output samples for drivers */
 
